@@ -6,16 +6,13 @@ describe 'ovn::controller' do
     { :ovn_remote                  => 'tcp:x.x.x.x:5000',
       :ovn_encap_type              => 'geneve',
       :ovn_encap_ip                => '1.2.3.4',
-      :ovn_encap_tos               => 0,
       :ovn_bridge_mappings         => ['physnet-1:br-1'],
       :ovn_bridge                  => 'br-int',
       :bridge_interface_mappings   => ['br-1:eth1'],
       :hostname                    => 'server1.example.com',
-      :enable_hw_offload           => false,
       :mac_table_size              => 20000,
       :ovn_remote_probe_interval   => 30000,
       :ovn_openflow_probe_interval => 8,
-      :ovn_monitor_all             => true,
       :ovn_transport_zones         => ['tz1'],
       :enable_ovn_match_northd     => false,
       :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
@@ -71,10 +68,6 @@ describe 'ovn::controller' do
         :value   => params[:ovn_bridge],
       )
 
-      is_expected.to contain_vs_config('external_ids:ovn-encap-tos').with(
-        :value   => 0,
-      )
-
       is_expected.to contain_vs_config('external_ids:ovn-remote-probe-interval').with(
         :value   => params[:ovn_remote_probe_interval],
       )
@@ -83,10 +76,6 @@ describe 'ovn::controller' do
         :value   => params[:ovn_openflow_probe_interval],
       )
 
-      is_expected.to contain_vs_config('external_ids:ovn-monitor-all').with(
-        :value   => params[:ovn_monitor_all],
-      )
-
       is_expected.to contain_vs_config('external_ids:ovn-transport-zones').with(
         :value   => params[:ovn_transport_zones],
       )
